@@ -1,10 +1,13 @@
-import six
+import warnings
+
+from django.utils import six
 from django.conf import global_settings
 from django.core.exceptions import ImproperlyConfigured
 
 from .utils import uppercase_attributes
+from .values import Value, setup_value
 
-__all__ = ['Settings']
+__all__ = ['Configuration']
 
 
 install_failure = ("django-configurations settings importer wasn't "
@@ -13,34 +16,39 @@ install_failure = ("django-configurations settings importer wasn't "
                    "http://django-configurations.readthedocs.org/")
 
 
-class SettingsBase(type):
+class ConfigurationBase(type):
 
     def __new__(cls, name, bases, attrs):
-        if bases != (object,) and bases[0].__name__ != 'NewBase':
+        # also check for "Configuration" here to handle the Settings class
+        # below remove it when we deprecate the Settings class
+        if (bases != (object,) and
+                bases[0].__name__ not in ('NewBase', 'Configuration')):
             # if this is actually a subclass in a settings module
             # we better check if the importer was correctly installed
             from . import importer
             if not importer.installed:
                 raise ImproperlyConfigured(install_failure)
         settings_vars = uppercase_attributes(global_settings)
-        parents = [base for base in bases if isinstance(base, SettingsBase)]
+        parents = [base for base in bases if isinstance(base,
+                                                        ConfigurationBase)]
         if parents:
             for base in bases[::-1]:
                 settings_vars.update(uppercase_attributes(base))
         attrs = dict(settings_vars, **attrs)
-        return super(SettingsBase, cls).__new__(cls, name, bases, attrs)
+        return super(ConfigurationBase, cls).__new__(cls, name, bases, attrs)
 
     def __repr__(self):
-        return "<Settings '%s.%s'>" % (self.__module__, self.__name__)
+        return "<Configuration '{0}.{1}'>".format(self.__module__,
+                                                  self.__name__)
 
 
-class Settings(six.with_metaclass(SettingsBase)):
+class Configuration(six.with_metaclass(ConfigurationBase)):
     """
     The base configuration class to inherit from.
 
     ::
 
-        class Develop(Settings):
+        class Develop(Configuration):
             EXTRA_AWESOME = True
 
             @property
@@ -65,3 +73,19 @@ class Settings(six.with_metaclass(SettingsBase)):
     @classmethod
     def post_setup(cls):
         pass
+
+    @classmethod
+    def setup(cls):
+        for name, value in uppercase_attributes(cls).items():
+            if isinstance(value, Value):
+                setup_value(cls, name, value)
+
+
+class Settings(Configuration):
+
+    @classmethod
+    def pre_setup(cls):
+        # make sure to remove the handling of the Settings class above when deprecating
+        warnings.warn("configurations.Settings was renamed to "
+                      "settings.Configuration and will be "
+                      "removed in 1.0", PendingDeprecationWarning)
