@@ -13,7 +13,7 @@ class InheritanceTests(TestCase):
                 DJANGO_SETTINGS_MODULE='configurations.tests.settings.single_inheritance')
     def test_inherited(self):
         from configurations.tests.settings import single_inheritance
-        self.assertEquals(single_inheritance.TEMPLATE_CONTEXT_PROCESSORS,
+        self.assertEqual(single_inheritance.TEMPLATE_CONTEXT_PROCESSORS,
                           global_settings.TEMPLATE_CONTEXT_PROCESSORS + (
                               'configurations.tests.settings.base.test_callback',
                           ))
@@ -23,7 +23,7 @@ class InheritanceTests(TestCase):
                 DJANGO_SETTINGS_MODULE='configurations.tests.settings.multiple_inheritance')
     def test_inherited2(self):
         from configurations.tests.settings import multiple_inheritance
-        self.assertEquals(multiple_inheritance.TEMPLATE_CONTEXT_PROCESSORS,
+        self.assertEqual(multiple_inheritance.TEMPLATE_CONTEXT_PROCESSORS,
                           global_settings.TEMPLATE_CONTEXT_PROCESSORS + (
                               'configurations.tests.settings.base.test_callback',
                               'configurations.tests.settings.base.test_callback',
@@ -34,7 +34,7 @@ class InheritanceTests(TestCase):
                 DJANGO_SETTINGS_MODULE='configurations.tests.settings.mixin_inheritance')
     def test_inherited3(self):
         from configurations.tests.settings import mixin_inheritance
-        self.assertEquals(mixin_inheritance.TEMPLATE_CONTEXT_PROCESSORS,
+        self.assertEqual(mixin_inheritance.TEMPLATE_CONTEXT_PROCESSORS,
                           global_settings.TEMPLATE_CONTEXT_PROCESSORS + (
                               'some_app.context_processors.processor1',
                               'some_app.context_processors.processor2',
