@@ -3,7 +3,8 @@ import os
 import sys
 
 if __name__ == "__main__":
-    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'configurations.tests.settings.main')
+    os.environ.setdefault('DJANGO_SETTINGS_MODULE',
+                          'configurations.tests.settings.main')
     os.environ.setdefault('DJANGO_CONFIGURATION', 'Test')
 
     from configurations.management import execute_from_command_line
